@@ -25,7 +25,8 @@
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
+#include <gtk/gtkwindow.h>
 #include <gconf/gconf-client.h>
 
 #include "gnome-settings-daemon.h"
@@ -39,7 +40,7 @@
 
 #define GTK_THEME_KEY "/desktop/gnome/interface/gtk_theme"
 
-GtkWidget *widget;
+static GtkWidget *widget;
 
 /*
  * Theme colour functions
@@ -170,8 +171,6 @@ scan_ad_directory (const char *path, GError **error)
 		return NULL;
 	}
 	while ((entry = g_dir_read_name (dir)) != NULL) {
-		int len;
-		len = strlen (entry);
 		if (g_str_has_suffix (entry, ".ad")) {
 			list = g_slist_prepend (list, g_strdup_printf ("%s/%s", path, entry));
 		}
@@ -320,8 +319,9 @@ apply_settings (GtkStyle *style)
 	return;
 }
 
-static void
-style_set_cb (GtkWidget *widget, GtkStyle *s, gpointer data)
+static void theme_changed (GtkSettings  *settings,
+                           GParamSpec   *pspec,
+			   GtkWidget    *widget)
 {
 	apply_settings (gtk_widget_get_style (widget));
 }
@@ -329,13 +329,25 @@ style_set_cb (GtkWidget *widget, GtkStyle *s, gpointer data)
 void
 gnome_settings_xrdb_init (GConfClient *client)
 {
-	widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	g_signal_connect (widget, "style-set", (GCallback)style_set_cb, NULL);
-	gtk_widget_ensure_style (widget);
 }
 
 void
 gnome_settings_xrdb_load (GConfClient *client)
 {
-	style_set_cb (widget, NULL, NULL);
+	static gboolean initialized = FALSE;
+
+	if (!initialized) 
+	  { /* the initialization is done here otherwise 
+	       gnome_settings_xsettings_load would generate 
+	       false hit as gtk-theme-name is set to Default in 
+	       gnome_settings_xsettings_init */
+	    GtkSettings *settings = gtk_settings_get_default ();
+	    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	    g_signal_connect (settings,
+			      "notify::gtk-theme-name",
+			      G_CALLBACK (theme_changed),
+			      widget);
+	    gtk_widget_ensure_style (widget); 
+	    initialized = TRUE;
+	  }
 }
