@@ -216,11 +216,12 @@ GSwitchItPluginManagerTogglePlugins (GSwitchItPluginManager *manager,
 
 void
 GSwitchItPluginManagerGroupChanged (GSwitchItPluginManager *manager,
+				    GtkWidget * notebook,
 				    int newGroup)
 {
 	FOREACH_INITED_PLUGIN ();
 	if (plugin->groupChangedCallback)
-		(*plugin->groupChangedCallback) (newGroup);
+		(*plugin->groupChangedCallback) (notebook, newGroup);
 	NEXT_INITED_PLUGIN ();
 }
 
