@@ -1,7 +1,8 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2002 CodeFactory AB
+ * Copyright (C) 2003-2005 Imendio HB
  * Copyright (C) 2002-2003 Richard Hult <richard@imendio.com>
+ * Copyright (C) 2002 CodeFactory AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,19 +24,18 @@
 #include <time.h>
 #include <string.h>
 #include <math.h>
+#include <glib/gi18n.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
+#include <gdk/gdkspawn.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-stock-icons.h>
-#include <libgnomeui/gnome-client.h>
-#include <libgnome/gnome-i18n.h>
 #include <gconf/gconf-client.h>
+
 #include "drwright.h"
 #include "drw-break-window.h"
 #include "drw-monitor.h"
 #include "drw-utils.h"
 #include "eggtrayicon.h"
-#include "egg-spawn.h"
 
 #define BLINK_TIMEOUT        200
 #define BLINK_TIMEOUT_MIN    120
@@ -133,12 +133,11 @@ static GList *  create_secondary_break_windows (void);
 static GtkItemFactoryEntry popup_items[] = {
 /*	{ N_("/_Enabled"),      NULL, GIF_CB (popup_enabled_cb),     POPUP_ITEM_ENABLED, "<ToggleItem>", NULL },*/
 	{ N_("/_Preferences"),  NULL, GIF_CB (popup_preferences_cb), 0,                  "<StockItem>",  GTK_STOCK_PREFERENCES },
-	{ N_("/_About"),        NULL, GIF_CB (popup_about_cb),       0,                  "<StockItem>",  GNOME_STOCK_ABOUT },
-	{ "/sep1",              NULL, 0,                             0,                  "<Separator>",  NULL },
+	{ N_("/_About"),        NULL, GIF_CB (popup_about_cb),       0,                  "<StockItem>",  GTK_STOCK_ABOUT },
+	{ "/sep1",              NULL, NULL,                          0,                  "<Separator>",  NULL },
 	{ N_("/_Take a Break"), NULL, GIF_CB (popup_break_cb),       POPUP_ITEM_BREAK,   "<Item>",       NULL }
 };
 
-GConfClient *client = NULL;
 extern gboolean debug;
 
 static void
@@ -290,6 +289,20 @@ stop_blinking (DrWright *dr)
 	/*gtk_widget_hide (GTK_WIDGET (dr->icon));*/
 }
 
+static gboolean
+grab_keyboard_on_window (GdkWindow *window,
+			 guint32    activate_time)
+{
+	GdkGrabStatus status;
+	
+	status = gdk_keyboard_grab (window, TRUE, activate_time);
+	if (status == GDK_GRAB_SUCCESS) {
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static gboolean
 maybe_change_state (DrWright *dr)
 {
@@ -375,6 +388,14 @@ maybe_change_state (DrWright *dr)
 		break;
 		
 	case STATE_BREAK_SETUP:
+		/* Don't allow more than one break window to coexist, can happen
+		 * if a break is manually enforced.
+		 */
+		if (dr->break_window) {
+			dr->state = STATE_BREAK;
+			break;
+		}
+		
 		stop_blinking (dr);
 		gtk_image_set_from_pixbuf (GTK_IMAGE (dr->icon_image), dr->red_bar);
 
@@ -401,6 +422,8 @@ maybe_change_state (DrWright *dr)
 
 		gtk_widget_show (dr->break_window);
 
+		grab_keyboard_on_window (dr->break_window->window, gtk_get_current_event_time ());
+		
 		dr->state = STATE_BREAK;
 		break;
 	       
@@ -504,13 +527,6 @@ gconf_notify_cb (GConfClient *client,
 			dr->state = STATE_START;
 		}
 	}
-/*	else if (!strcmp (entry->key, GCONF_PATH "/warn_time")) {
-		if (entry->value->type == GCONF_VALUE_INT) {
-			dr->warn_time = 60 * gconf_value_get_int (entry->value);
-			dr->state = STATE_START;
-		}
-	}
-*/
 	else if (!strcmp (entry->key, GCONF_PATH "/break_time")) {
 		if (entry->value->type == GCONF_VALUE_INT) {
 			dr->break_time = 60 * gconf_value_get_int (entry->value);
@@ -538,7 +554,7 @@ popup_break_cb (gpointer   callback_data,
 		guint      action,
 		GtkWidget *widget)
 {
-	DrWright  *dr = callback_data;
+	DrWright *dr = callback_data;
 
 	if (dr->enabled) {
 		dr->state = STATE_BREAK_SETUP;
@@ -556,7 +572,7 @@ popup_preferences_cb (gpointer   callback_data,
 
 	screen = gtk_widget_get_screen (widget);
 
-	if (!egg_spawn_command_line_async_on_screen ("gnome-keyboard-properties --typing-break", screen, &error)) {
+	if (!gdk_spawn_command_line_on_screen (screen, "gnome-keyboard-properties --typing-break", &error)) {
 		GtkWidget *error_dialog;
 
 		error_dialog = gtk_message_dialog_new (NULL, 0,
@@ -574,6 +590,14 @@ popup_preferences_cb (gpointer   callback_data,
 	}
 }
 
+static void
+about_response_cb (GtkWidget *dialog,
+		   gint       response,
+		   gpointer   user_data)
+{
+	gtk_widget_destroy (dialog);
+}
+	
 static void
 popup_about_cb (gpointer   callback_data,
 		guint      action,
@@ -634,8 +658,10 @@ popup_about_cb (gpointer   callback_data,
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 	
 	gtk_widget_show_all (about_window);
-	gtk_dialog_run (GTK_DIALOG (about_window));
-	gtk_widget_destroy (about_window);
+
+	g_signal_connect (about_window,
+			  "response", G_CALLBACK (about_response_cb),
+			  NULL);
 }
 
 static void
@@ -723,7 +749,8 @@ break_window_done_cb (GtkWidget *window,
 	
 	dr->state = STATE_BREAK_DONE_SETUP;
 	dr->break_window = NULL;
-	
+
+	update_tooltip (dr);
 	maybe_change_state (dr);
 }
 
@@ -882,6 +909,7 @@ drwright_new (void)
 {
 	DrWright  *dr;
 	GtkWidget *item;
+	GConfClient *client;
 
         dr = g_new0 (DrWright, 1);
 
@@ -901,10 +929,7 @@ drwright_new (void)
 	dr->type_time = 60 * gconf_client_get_int (
 		client, GCONF_PATH "/type_time", NULL);
 	
-/*	dr->warn_time = 60 * gconf_client_get_int (
-		client, GCONF_PATH /warn_time", NULL);
-*/
-	dr->warn_time = MIN (dr->type_time / 10, 60*5);
+	dr->warn_time = MIN (dr->type_time / 12, 60*3);
 	
 	dr->break_time = 60 * gconf_client_get_int (
 		client, GCONF_PATH "/break_time", NULL);
@@ -914,6 +939,8 @@ drwright_new (void)
 		GCONF_PATH "/enabled",
 		NULL);
 
+	g_object_unref (client);
+
 	if (debug) {
 		setup_debug_values (dr);
 	}
@@ -958,7 +985,7 @@ drwright_new (void)
 
 	init_tray_icon (dr);
 	
-	g_timeout_add (15*1000,
+	g_timeout_add (10*1000,
 		       (GSourceFunc) update_tooltip,
 		       dr);
 	g_timeout_add (500,
